OperationKind

Enum OperationKind 

pub enum OperationKind {
    CreateTable(Table),
    DropTable(TableName),
    RenameTable {
        from: TableName,
        to: TableName,
    },
    AddColumn {
        table: TableName,
        column: Column,
    },
    DropColumn {
        table: TableName,
        column: ColumnName,
    },
    RenameColumn {
        table: TableName,
        from: ColumnName,
        to: ColumnName,
    },
    AlterColumn {
        table: TableName,
        column: ColumnName,
    },
    AddConstraint {
        table: TableName,
        constraint: Constraint,
    },
    DropConstraint {
        table: TableName,
        constraint: ConstraintName,
    },
    AddIndex {
        table: TableName,
        index: Index,
    },
    DropIndex {
        table: TableName,
        index: IndexName,
    },
    Backfill(Box<CheckedMutation>),
}
A precisely described schema edit.

Variants



CreateTable(Table)

Create a table.



DropTable(TableName)

Drop a table and its data.



RenameTable

Rename a table.

Fields

from: TableName

Old name.

to: TableName

New name.



AddColumn

Add a column.

Fields

table: TableName

Owning table.

column: Column

New column.



DropColumn

Drop a column and its data.

Fields

table: TableName

Owning table.

column: ColumnName

Removed column.



RenameColumn

Rename a column.

Fields

table: TableName

Owning table.

from: ColumnName

Old name.

to: ColumnName

New name.



AlterColumn

Alter a column domain, nullability, default, or generation rule.

Fields

table: TableName

Owning table.

column: ColumnName

Changed column.



AddConstraint

Add a constraint.

Fields

table: TableName

Owning table.

constraint: Constraint

Added constraint.



DropConstraint

Drop a constraint.

Fields

table: TableName

Owning table.

constraint: ConstraintName

Removed constraint.



AddIndex

Add an index.

Fields

table: TableName

Owning table.

index: Index

Added index.



DropIndex

Drop an index.

Fields

table: TableName

Owning table.

index: IndexName

Removed index.



Backfill(Box<CheckedMutation>)

Run an already admitted data mutation during the transition.