pub enum OperationKind {
CreateTable(Table),
DropTable(TableName),
RenameTable {
from: TableName,
to: TableName,
},
AddColumn {
table: TableName,
column: Column,
},
DropColumn {
table: TableName,
column: ColumnName,
},
RenameColumn {
table: TableName,
from: ColumnName,
to: ColumnName,
},
AlterColumn {
table: TableName,
column: ColumnName,
},
AddConstraint {
table: TableName,
constraint: Constraint,
},
DropConstraint {
table: TableName,
constraint: ConstraintName,
},
AddIndex {
table: TableName,
index: Index,
},
DropIndex {
table: TableName,
index: IndexName,
},
Backfill(Box<CheckedMutation>),
}Expand description
A precisely described schema edit.
Variants
CreateTable(Table)
Create a table.
DropTable(TableName)
Drop a table and its data.
RenameTable
Rename a table.
AddColumn
Add a column.
DropColumn
Drop a column and its data.
RenameColumn
Rename a column.
AlterColumn
Alter a column domain, nullability, default, or generation rule.
AddConstraint
Add a constraint.
DropConstraint
Drop a constraint.
AddIndex
Add an index.
DropIndex
Drop an index.
Backfill(Box<CheckedMutation>)
Run an already admitted data mutation during the transition.